from django.shortcuts import render, reverse
from django.views.generic import DetailView, ListView, CreateView
from django.http import HttpResponseRedirect
from guardian.mixins import PermissionRequiredMixin, PermissionListMixin
from guardian.decorators import permission_required
from guardian.shortcuts import assign_perm
from guardian.utils import get_anonymous_user
from . import models
from . import forms


class PublicKeyListView(PermissionListMixin, ListView):
    model = models.SSHPublicKey
    permission_required = ['view_sshpublickey']

@permission_required('ssh.add_sshpublickey')
def publickey_create(request):
    if request.method == 'POST':
        form = forms.PublicKeyCreateForm(request.POST)
        if form.is_valid():
            pk = models.SSHPublicKey()
            pk.hostname = form.cleaned_data['hostname']
            pk.port = form.cleaned_data['port']
            pk.client_cert = form.cleaned_data['client_cert']
            pk.keytype, pk.key = form.cleaned_data['keystring'][:2]
            pk.save()

            assign_perm('view_sshpublickey', request.user, pk)
            assign_perm('change_sshpublickey', request.user, pk)

            if form.cleaned_data['public']:
                assign_perm('view_sshpublickey',
                            get_anonymous_user(),
                            pk)
            return HttpResponseRedirect(reverse('ssh-list'))

    # if a GET (or any other method) we'll create a blank form
    else:
        form = forms.PublicKeyCreateForm()

    return render(request,
                  'ssh/sshpublickey_create.html',
                  {'form': form})

class PublicKeyDetailView(PermissionRequiredMixin, DetailView):
    model = models.SSHPublicKey
    context_object_name = "publickey"
    permission_required = ['view_sshpublickey']

class PublicKeyDownloadOpenSshView(PermissionRequiredMixin, DetailView):
    model = models.SSHPublicKey
    template_name = "ssh/sshpublickey_download_openssh.html"
    content_type = "text/plain"
    permission_required = ['view_sshpublickey']

class PublicKeyDownloadRfc4716View(PermissionRequiredMixin, DetailView):
    model = models.SSHPublicKey
    template_name = "ssh/sshpublickey_download_rfc4716.html"
    content_type = "text/plain"
    permission_required = ['view_sshpublickey']
